@@ -4,12 +4,12 @@ source "$TEST_TOP/common"
 
 check_prereq btrfs
 
-echo "extracting image default_case.tar.xz" >> "$RESULTS"
+_log "extracting image default_case.tar.xz"
 tar --no-same-owner -xJf default_case.tar.xz || \
 	_fail "failed to extract default_case.tar.xz"
 check_image test.img
 
-echo "extracting image skinny_case.tar.xz" >> "$RESULTS"
+_log "extracting image skinny_case.tar.xz"
 tar --no-same-owner -xJf skinny_case.tar.xz || \
 	_fail "failed to extract skinny_case.tar.xz"
 check_image test.img
